pub enum FinalUpperEdge {
Exclusive,
Inclusive,
}Expand description
Policy for a value exactly equal to an axis’s final upper edge.
Variants
Exclusive
Treat the final upper edge as outside the bounded axis.
Inclusive
Assign the final upper edge to the last bin.