Predicate

Enum Predicate 

pub enum Predicate {
    Compare {
        lhs: Expr,
        op: Comparison,
        rhs: Expr,
    },
    And(Box<Self>, Box<Self>),
    Or(Box<Self>, Box<Self>),
    Not(Box<Self>),
    Between {
        value: Expr,
        lower: Expr,
        upper: Expr,
        closure: IntervalClosure,
    },
}
Boolean expression used to select events from a dataset.

Variants



Compare

Compare two scalar expressions.

Fields

lhs: Expr

Left-hand expression.

op: Comparison

Comparison operation.

rhs: Expr

Right-hand expression.



And(Box<Self>, Box<Self>)

Require both child predicates to hold.



Or(Box<Self>, Box<Self>)

Require either child predicate to hold.



Not(Box<Self>)

Negate a predicate.



Between

Test whether a value lies between two bounds.

Fields

value: Expr

Expression whose value is tested.

lower: Expr

Lower bound expression.

upper: Expr

Upper bound expression.

closure: IntervalClosure

Endpoint inclusion policy.

Implementations

Source

impl Predicate

pub fn compare( lhs: impl Into<Expr>, op: Comparison, rhs: impl Into<Expr>, ) -> Self

Creates a comparison predicate.

pub fn lt(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self

Creates a less-than predicate.

pub fn le(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self

Creates a less-than-or-equal predicate.

pub fn gt(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self

Creates a greater-than predicate.

pub fn ge(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self

Creates a greater-than-or-equal predicate.

pub fn eq(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self

Creates an equality predicate.

pub fn ne(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self

Creates an inequality predicate.

pub fn and(self, rhs: Self) -> Self

Combines this predicate with rhs using logical AND.

pub fn or(self, rhs: Self) -> Self

Combines this predicate with rhs using logical OR.

pub fn between( value: impl Into<Expr>, lower: impl Into<Expr>, upper: impl Into<Expr>, ) -> Self

Creates a closed-interval predicate.

pub fn between_with( value: impl Into<Expr>, lower: impl Into<Expr>, upper: impl Into<Expr>, closure: IntervalClosure, ) -> Self

Creates an interval predicate with an explicit endpoint policy.