pub struct JointHistogramDiagnostics { /* private fields */ }Expand description
Aggregate diagnostics for events that could not be placed in a joint histogram.
Implementations
Sourceimpl JointHistogramDiagnostics
impl JointHistogramDiagnostics
Sourcepub fn nonfinite_count(&self) -> u64
pub fn nonfinite_count(&self) -> u64
Number of events with a nonfinite coordinate or weight.
Sourcepub fn nonfinite_weight(&self) -> f64
pub fn nonfinite_weight(&self) -> f64
Sum of finite event weights classified as nonfinite.
Sourcepub fn out_of_range_count(&self) -> u64
pub fn out_of_range_count(&self) -> u64
Number of finite events outside at least one axis.
Sourcepub fn out_of_range_weight(&self) -> f64
pub fn out_of_range_weight(&self) -> f64
Sum of weights for finite events outside at least one axis.