pub enum Predicate {
Compare {
lhs: Expr,
op: Comparison,
rhs: Expr,
},
And(Box<Self>, Box<Self>),
Or(Box<Self>, Box<Self>),
Not(Box<Self>),
Between {
value: Expr,
lower: Expr,
upper: Expr,
closure: IntervalClosure,
},
}Expand description
Boolean expression used to select events from a dataset.
Variants
Compare
Compare two scalar expressions.
Fields

op: ComparisonComparison operation.
And(Box<Self>, Box<Self>)
Require both child predicates to hold.
Or(Box<Self>, Box<Self>)
Require either child predicate to hold.
Not(Box<Self>)
Negate a predicate.
Between
Test whether a value lies between two bounds.
Implementations
Sourceimpl Predicate
impl Predicate
Sourcepub fn compare(
lhs: impl Into<Expr>,
op: Comparison,
rhs: impl Into<Expr>,
) -> Self
pub fn compare( lhs: impl Into<Expr>, op: Comparison, rhs: impl Into<Expr>, ) -> Self
Creates a comparison predicate.
Sourcepub fn le(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self
pub fn le(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self
Creates a less-than-or-equal predicate.
Sourcepub fn gt(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self
pub fn gt(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self
Creates a greater-than predicate.
Sourcepub fn ge(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self
pub fn ge(lhs: impl Into<Expr>, rhs: impl Into<Expr>) -> Self
Creates a greater-than-or-equal predicate.
Sourcepub fn between(
value: impl Into<Expr>,
lower: impl Into<Expr>,
upper: impl Into<Expr>,
) -> Self
pub fn between( value: impl Into<Expr>, lower: impl Into<Expr>, upper: impl Into<Expr>, ) -> Self
Creates a closed-interval predicate.
Sourcepub fn between_with(
value: impl Into<Expr>,
lower: impl Into<Expr>,
upper: impl Into<Expr>,
closure: IntervalClosure,
) -> Self
pub fn between_with( value: impl Into<Expr>, lower: impl Into<Expr>, upper: impl Into<Expr>, closure: IntervalClosure, ) -> Self
Creates an interval predicate with an explicit endpoint policy.