pub struct CpuBackend;Expand description
Prepares compiled models for CPU execution.
Implementations
Sourceimpl CpuBackend
impl CpuBackend
Sourcepub fn prepare_for_execution(
&self,
model: &CompiledModel,
execution: &Execution,
) -> RuntimeResult<CpuPlan>
pub fn prepare_for_execution( &self, model: &CompiledModel, execution: &Execution, ) -> RuntimeResult<CpuPlan>
Prepares a model using the policies resolved by an execution context.
Errors
Returns RuntimeError when model lowering or differentiation fails,
or the requested precision is unsupported for the model.
Sourcepub fn prepare(&self, model: &CompiledModel) -> CpuPlan
pub fn prepare(&self, model: &CompiledModel) -> CpuPlan
Prepares a model with forward autodiff and automatic execution-mode selection.
Panics
Panics if forward differentiation or executable-plan construction fails for the compiled model.
Sourcepub fn prepare_with_execution_mode(
&self,
model: &CompiledModel,
execution_mode: CpuExecutionMode,
) -> CpuPlan
pub fn prepare_with_execution_mode( &self, model: &CompiledModel, execution_mode: CpuExecutionMode, ) -> CpuPlan
Prepares a model with an explicit scalar-kernel execution mode.
Panics
Panics if forward differentiation or executable-plan construction fails for the compiled model.
Sourcepub fn prepare_with_autodiff_mode(
&self,
model: &CompiledModel,
mode: AutodiffMode,
) -> AutodiffResult<CpuPlan>
pub fn prepare_with_autodiff_mode( &self, model: &CompiledModel, mode: AutodiffMode, ) -> AutodiffResult<CpuPlan>
Prepares a model with an explicit automatic-differentiation mode.
Errors
Returns laddu_autodiff::AutodiffError when model lowering or
differentiation fails.
Sourcepub fn prepare_with_modes(
&self,
model: &CompiledModel,
autodiff_mode: AutodiffMode,
execution_mode: CpuExecutionMode,
) -> AutodiffResult<CpuPlan>
pub fn prepare_with_modes( &self, model: &CompiledModel, autodiff_mode: AutodiffMode, execution_mode: CpuExecutionMode, ) -> AutodiffResult<CpuPlan>
Prepares a model with explicit autodiff and scalar execution modes.
Errors
Returns laddu_autodiff::AutodiffError when model lowering or
differentiation fails.