pub struct DeviceIdentity {
pub adapter_index: usize,
pub vendor_id: u32,
pub device_id: u32,
pub pci_bus_id: String,
}Expand description
Stable information used to match a runtime accelerator to platform telemetry.
Fields
adapter_index: usizeBackend adapter index.
vendor_id: u32PCI vendor identifier, or zero when unavailable.
device_id: u32PCI device identifier, or zero when unavailable.
pci_bus_id: StringPCI bus identifier, or an empty string when unavailable.